PCB Environment: Data Fields - Variables

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all variables with links to the structures/unions they belong to:

### - r -

- R : Action::Result
- Raster : UserAgent
- RatsNestVisible : UserSettings
- RED : Color
- ref_len : dsn::Connection
- RENDER_MASK_ALL : PCBoardMesh
- RENDER_MASK_COMPONENTS : PCBoardMesh
- RENDER_MASK_PINS : PCBoardMesh
- resolution : dsn::PCB
- resolution_ex : dsn::PCB
- RestartIndex : PCBoardMesh
- Reward : UserSettings
- RewardSum : ResultRecord
- RouteGuard : UserAgent
- RoutePreview : UserSettings
- Router : Action::Result, ResultRecord
- RouteTo : UserAgent
- RRRTrack : NavKeepoutCounts